==> applet-service-1.0.0-vg-20210508.071926-7-sources.jar: com/bizvane/appletservice/models/vo/ShopHomePageVo.java <==
package com.bizvane.appletservice.models.vo;

import java.util.List;

/**
 * 积分商城首页
 *
 * @author gs
 * @date 2019/3/18
 */
public class ShopHomePageVo {
    //轮播图
    private List<RotationChartVo> rotationChart;
    //轮播图速度控制
    private String imgInterval;
    private String memberCode;
    private String memberName;
    //积分
    private String InterGerge;
    //微信头像
    private String weChatHead;
    //分类商品列表
    private List<ShopClassifyMapVo> classification;
    //热门兑换商品
    private List<ShopStoreVo> popular;
    private String wxNick;
    private String headPortraits;

    private String brandLogo;

    public String getBrandLogo() {
        return brandLogo;
    }

    public void setBrandLogo(String brandLogo) {
        this.brandLogo = brandLogo;
    }

    public List<RotationChartVo> getRotationChart() {
        return rotationChart;
    }

    public void setRotationChart(List<RotationChartVo> rotationChart) {
        this.rotationChart = rotationChart;
    }

    public String getImgInterval() {
        return imgInterval;
    }

    public void setImgInterval(String imgInterval) {
        this.imgInterval = imgInterval;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }

    public String getInterGerge() {
        return InterGerge;
    }

    public void setInterGerge(String interGerge) {
        InterGerge = interGerge;
    }

    public String getWeChatHead() {
        return weChatHead;
    }

    public void setWeChatHead(String weChatHead) {
        this.weChatHead = weChatHead;
    }

    public List<ShopClassifyMapVo> getClassification() {
        return classification;
    }

    public void setClassification(List<ShopClassifyMapVo> classification) {
        this.classification = classification;
    }

    public List<ShopStoreVo> getPopular() {
        return popular;
    }

    public void setPopular(List<ShopStoreVo> popular) {
        this.popular = popular;
    }

    public String getWxNick() {
        return wxNick;
    }

    public void setWxNick(String wxNick) {
        this.wxNick = wxNick;
    }

    public String getHeadPortraits() {
        return headPortraits;
    }

    public void setHeadPortraits(String headPortraits) {
        this.headPortraits = headPortraits;
    }
}

==> applet-service-1.5.2-vg-20220723.103508-7-sources.jar: com/bizvane/appletservice/models/vo/ShopHomePageVo.java <==
package com.bizvane.appletservice.models.vo;

import java.util.List;

/**
 * 积分商城首页
 *
 * @author gs
 * @date 2019/3/18
 */
public class ShopHomePageVo {
    //轮播图
    private List<RotationChartVo> rotationChart;
    //轮播图速度控制
    private String imgInterval;
    private String memberCode;
    private String memberName;
    //积分
    private String InterGerge;
    //微信头像
    private String weChatHead;
    //分类商品列表
    private List<ShopClassifyMapVo> classification;
    //热门兑换商品
    private List<ShopStoreVo> popular;
    private String wxNick;
    private String headPortraits;

    private String brandLogo;

    private Boolean judgeIntegralActivity = Boolean.FALSE;

    private Boolean alertStatus = Boolean.FALSE;

    private String alertImg;

    private Byte alertType;

    private Integer integralActivityId;

    public String getBrandLogo() {
        return brandLogo;
    }

    public void setBrandLogo(String brandLogo) {
        this.brandLogo = brandLogo;
    }

    public List<RotationChartVo> getRotationChart() {
        return rotationChart;
    }

    public void setRotationChart(List<RotationChartVo> rotationChart) {
        this.rotationChart = rotationChart;
    }

    public String getImgInterval() {
        return imgInterval;
    }

    public void setImgInterval(String imgInterval) {
        this.imgInterval = imgInterval;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }

    public String getInterGerge() {
        return InterGerge;
    }

    public void setInterGerge(String interGerge) {
        InterGerge = interGerge;
    }

    public String getWeChatHead() {
        return weChatHead;
    }

    public void setWeChatHead(String weChatHead) {
        this.weChatHead = weChatHead;
    }

    public List<ShopClassifyMapVo> getClassification() {
        return classification;
    }

    public void setClassification(List<ShopClassifyMapVo> classification) {
        this.classification = classification;
    }

    public List<ShopStoreVo> getPopular() {
        return popular;
    }

    public void setPopular(List<ShopStoreVo> popular) {
        this.popular = popular;
    }

    public String getWxNick() {
        return wxNick;
    }

    public void setWxNick(String wxNick) {
        this.wxNick = wxNick;
    }

    public String getHeadPortraits() {
        return headPortraits;
    }

    public void setHeadPortraits(String headPortraits) {
        this.headPortraits = headPortraits;
    }

    public Boolean getJudgeIntegralActivity() {
        return judgeIntegralActivity;
    }

    public void setJudgeIntegralActivity(Boolean judgeIntegralActivity) {
        this.judgeIntegralActivity = judgeIntegralActivity;
    }

    public Boolean getAlertStatus() {
        return alertStatus;
    }

    public void setAlertStatus(Boolean alertStatus) {
        this.alertStatus = alertStatus;
    }

    public String getAlertImg() {
        return alertImg;
    }

    public void setAlertImg(String alertImg) {
        this.alertImg = alertImg;
    }

    public Byte getAlertType() {
        return alertType;
    }

    public void setAlertType(Byte alertType) {
        this.alertType = alertType;
    }

    public Integer getIntegralActivityId() {
        return integralActivityId;
    }

    public void setIntegralActivityId(Integer integralActivityId) {
        this.integralActivityId = integralActivityId;
    }
}
